"use strict";
/*
 * Copyright (c) 2019, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const diffManager_1 = require("../../../processors/diffManager");
const sourcePathParser_1 = require("../../../sourcePathParser");
const utils_1 = require("../../../utils");
const validations_1 = require("../../../validations");
command_1.core.Messages.importMessagesDirectory(__dirname);
const messages = command_1.core.Messages.loadMessages('@salesforce/sfdx-diff', 'diff');
class Diff extends command_1.SfdxCommand {
    async run() {
        try {
            utils_1.usernameHandler.initialize(this.flags.targetusername);
            const sourcePath = utils_1.getAbsolutePath(this.flags.sourcepath);
            await validations_1.default.isValidProject();
            await validations_1.default.validateSourcePath(sourcePath);
            const sourcePathParser = new sourcePathParser_1.default(sourcePath);
            const metadataInfo = sourcePathParser.getMetadataInfo();
            validations_1.default.validateMetadataInfo(metadataInfo, sourcePath);
            const conn = this.org.getConnection();
            const mdManagerClass = new diffManager_1.default(metadataInfo, conn);
            const result = await mdManagerClass.run();
            this.ux.log('This command is currently in a beta program for usage with the Salesforce Extensions for VSCode.');
            const jsonResult = this.formatResult(result, sourcePath, mdManagerClass.getMdFileName());
            return jsonResult;
        }
        catch (e) {
            return Promise.reject(e);
        }
    }
    formatResult(remote, sourcePath, fileName) {
        return {
            remote,
            local: sourcePath,
            fileName
        };
    }
}
Diff.description = messages.getMessage('command_description');
Diff.longDescription = messages.getMessage('command_long_description');
Diff.flagsConfig = {
    sourcepath: command_1.flags.string({
        char: 'p',
        description: messages.getMessage('source_path_flag_description'),
        longDescription: messages.getMessage('source_path_flag_long_description'),
        required: true
    })
};
Diff.requiresUsername = true;
Diff.requiresProject = true;
exports.default = Diff;
//# sourceMappingURL=diff.js.map