"use strict";
/*
 * Copyright (c) 2019, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const path = require("path");
const metadataInfos = require("./metadataInfos.json");
command_1.core.Messages.importMessagesDirectory(__dirname);
const messages = command_1.core.Messages.loadMessages('@salesforce/sfdx-diff', 'diff');
class MetadataInfoManager {
    constructor(infos = metadataInfos) {
        this.infos = infos;
    }
    getSupportedMetadataTypes() {
        return Object.values(this.infos).map((info) => info.parentFolder
            ? `${info.parentFolder}${path.sep}<BundleName>${path.sep}${info.metadataName}`
            : info.metadataName);
    }
    getMetadataInfoByPath(filePathWOMetaXMLSuffix) {
        const mdInfo = this.getMetadataInfoBasedOnParentPath(filePathWOMetaXMLSuffix, this.filterMetadataInfosByFilePathSuffix(filePathWOMetaXMLSuffix));
        if (mdInfo === null || typeof mdInfo === 'undefined') {
            throw Error(messages.getMessage('path_not_supported', [
                filePathWOMetaXMLSuffix,
                this.getSupportedMetadataTypes().join(', ')
            ]));
        }
        return this.enrichedMetadataInfo(mdInfo, filePathWOMetaXMLSuffix);
    }
    enrichedMetadataInfo(mdInfo, filePathWOMetaXMLSuffix) {
        let fileName = path.basename(filePathWOMetaXMLSuffix);
        fileName = fileName
            .replace(new RegExp(mdInfo.suffix + '$'), '')
            .replace(/\.$/, '');
        mdInfo.fileName = fileName;
        return mdInfo;
    }
    filterMetadataInfosByFilePathSuffix(filePathWOMetaXMLSuffix) {
        return Object.values(this.infos).filter((info) => filePathWOMetaXMLSuffix.endsWith(info.suffix));
    }
    /*
     * It's possible for there to be multiple matches (SVG and CSS types). Return the
     * correct match based on the parent path. If neither parent path appears to be
     * present then do not return any matches. If the match doesn't have a parent,
     * return it (this will happen in the event of the Controller.js for example).
     */
    getMetadataInfoBasedOnParentPath(filePathWOMetaXMLSuffix, metadataInfo) {
        if (metadataInfo.length === 1) {
            return metadataInfo[0];
        }
        return Object.values(metadataInfo).find(match => match.parentFolder
            ? filePathWOMetaXMLSuffix.match(new RegExp(match.parentFolder +
                '(.*)' +
                path.basename(filePathWOMetaXMLSuffix) +
                '$')) !== null
            : true);
    }
}
exports.default = MetadataInfoManager;
//# sourceMappingURL=metadataInfoManager.js.map