"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
 * Copyright (c) 2019, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
const command_1 = require("@salesforce/command");
const utils_1 = require("../utils");
const fileSystemHandler_1 = require("../utils/fileSystemHandler");
command_1.core.Messages.importMessagesDirectory(__dirname);
const messages = command_1.core.Messages.loadMessages('@salesforce/sfdx-diff', 'diff');
class AuraProcessor {
    constructor(metadataInfo, connection) {
        this.metadataInfo = metadataInfo;
        this.connection = connection;
        this.cacheFolder = 'aura';
    }
    async getMetadata() {
        let cachedFilePath;
        try {
            const queryResult = (await this.connection.tooling.query(this.buildQuery()));
            if (queryResult && queryResult.records.length === 0) {
                const username = await utils_1.usernameHandler.getUsername();
                throw new Error(messages.getMessage('error_md_not_present_in_org', [
                    this.getMdFileName(),
                    username
                ]));
            }
            cachedFilePath = await this.getCachedFilePath();
            fileSystemHandler_1.createMdCacheFile(cachedFilePath, queryResult.records[0].Source);
        }
        catch (err) {
            throw new Error(messages.getMessage('error_in_processor', ['AuraProcessor', err]));
        }
        return cachedFilePath;
    }
    async getCachedFilePath() {
        return await utils_1.createBundleCacheFilePath(this.cacheFolder, this.metadataInfo.fileName, this.getMdFileName());
    }
    getMdFileName() {
        if (this.metadataInfo.suffix.indexOf('.') > -1) {
            return `${this.metadataInfo.fileName}${this.metadataInfo.suffix}`;
        }
        return `${this.metadataInfo.fileName}.${this.metadataInfo.suffix}`;
    }
    buildQuery() {
        return `Select Id, AuraDefinitionBundleId, AuraDefinitionBundle.DeveloperName, DefType, Source from ${this.metadataInfo.metadataName} where AuraDefinitionBundle.DeveloperName = '${this.metadataInfo.fileName}' and DefType = '${this.metadataInfo.type}'`;
    }
}
exports.default = AuraProcessor;
//# sourceMappingURL=auraProcessor.js.map