"use strict";
/*
 * Copyright (c) 2019, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const apexProcessor_1 = require("./apexProcessor");
const auraProcessor_1 = require("./auraProcessor");
const lwcProcessor_1 = require("./lwcProcessor");
const visualforceProcessor_1 = require("./visualforceProcessor");
command_1.core.Messages.importMessagesDirectory(__dirname);
const messages = command_1.core.Messages.loadMessages('@salesforce/sfdx-diff', 'diff');
class DiffManager {
    constructor(metadataInfo, connection) {
        switch (metadataInfo.metadataName) {
            case 'ApexClass':
            case 'ApexTrigger':
                this.mdProcessor = new apexProcessor_1.default(metadataInfo, connection);
                break;
            case 'ApexComponent':
            case 'ApexPage':
                this.mdProcessor = new visualforceProcessor_1.default(metadataInfo, connection);
                break;
            case 'AuraDefinition':
                this.mdProcessor = new auraProcessor_1.default(metadataInfo, connection);
                break;
            case 'LightningComponentResource':
                this.mdProcessor = new lwcProcessor_1.default(metadataInfo, connection);
                break;
            default:
                throw Error(messages.getMessage('error_no_processor', [metadataInfo.metadataName]));
        }
    }
    getMdFileName() {
        return this.mdProcessor.getMdFileName();
    }
    async run() {
        return await this.mdProcessor.getMetadata();
    }
}
exports.default = DiffManager;
//# sourceMappingURL=diffManager.js.map