"use strict";
/*
 * Copyright (c) 2019, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
const core_1 = require("@salesforce/core");
const path = require("path");
core_1.Messages.importMessagesDirectory(__dirname);
const messages = core_1.Messages.loadMessages('@salesforce/sfdx-diff', 'sfdxPackageDirectories');
class SfdxPackageDirectories {
    static async pathIsInPackageDirectory(sourcePath) {
        const absoluteSourcePath = path.resolve(sourcePath);
        const packageDirectoriesAbsolutePaths = await SfdxPackageDirectories.getPackageDirectoriesAbsolutePaths();
        const isInPackageDirectory = SfdxPackageDirectories.isInPackageDirectory(absoluteSourcePath, packageDirectoriesAbsolutePaths);
        return Promise.resolve(isInPackageDirectory);
    }
    static async getPackageDirectoriesAbsolutePaths() {
        const project = await core_1.SfdxProject.resolve();
        const projectPath = project.getPath();
        const packageDirectoriesPaths = await this.getPackageDirectoryPaths();
        return packageDirectoriesPaths.map(directoryPath => path.join(projectPath, directoryPath));
    }
    static async getPackageDirectoryPaths() {
        const project = await core_1.SfdxProject.resolve();
        const projectJson = await project.resolveProjectConfig();
        const packageDirectories = projectJson.packageDirectories;
        if (packageDirectories) {
            const packageDirectoriesPaths = [];
            packageDirectories.forEach(packageDir => {
                if (packageDir) {
                    const packageDirectory = packageDir;
                    if (packageDirectory.path) {
                        let dirPath = packageDirectory.path;
                        dirPath = this.sanitizePath(dirPath);
                        packageDirectoriesPaths.push(dirPath);
                    }
                }
            });
            if (packageDirectoriesPaths.length === 0) {
                throw new Error(messages.getMessage('no_package_directories_paths_found'));
            }
            return packageDirectoriesPaths;
        }
        else {
            throw new Error(messages.getMessage('no_package_directories_found'));
        }
    }
    static sanitizePath(filePath) {
        filePath = filePath.trim();
        if (filePath.startsWith('.')) {
            filePath = filePath.substring(1);
        }
        if (filePath.startsWith(path.sep)) {
            filePath = filePath.substring(1);
        }
        return filePath;
    }
    static isInPackageDirectory(sourcePath, packageDirectoryPaths) {
        let filePathIsInPackageDirectory = false;
        for (const packageDirectoryPath of packageDirectoryPaths) {
            if (sourcePath.startsWith(packageDirectoryPath)) {
                filePathIsInPackageDirectory = true;
                break;
            }
        }
        return filePathIsInPackageDirectory;
    }
}
exports.default = SfdxPackageDirectories;
//# sourceMappingURL=sfdxPackageDirectories.js.map